@@ -23,7 +23,6 @@ import (
 	"github.com/openshift/library-go/pkg/operator/v1helpers"
 	"k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
-	"k8s.io/client-go/dynamic"
 	"k8s.io/client-go/kubernetes"
 )
 
@@ -33,10 +32,6 @@ func RunOperator(ctx *controllercmd.ControllerContext) error {
 	if err != nil {
 		return err
 	}
-	dynamicClient, err := dynamic.NewForConfig(ctx.KubeConfig)
-	if err != nil {
-		return err
-	}
 	configClient, err := configv1client.NewForConfig(ctx.KubeConfig)
 	if err != nil {
 		return err
@@ -76,6 +71,7 @@ func RunOperator(ctx *controllercmd.ControllerContext) error {
 	targetConfigController := targetconfigcontroller.NewTargetConfigController(
 		os.Getenv("IMAGE"),
 		os.Getenv("OPERATOR_IMAGE"),
+		os.Getenv("CLUSTER_POLICY_CONTROLLER_IMAGE"),
 		kubeInformersForNamespaces,
 		operatorClient,
 		kubeClient,
@@ -99,7 +95,6 @@ func RunOperator(ctx *controllercmd.ControllerContext) error {
 		WithPruning([]string{"cluster-kube-controller-manager-operator", "prune"}, "kube-controller-manager-pod").
 		WithResources(operatorclient.TargetNamespace, "kube-controller-manager", deploymentConfigMaps, deploymentSecrets).
 		WithCerts("kube-controller-manager-certs", CertConfigMaps, CertSecrets).
-		WithServiceMonitor(dynamicClient).
 		WithVersioning(operatorclient.OperatorNamespace, "kube-controller-manager", versionRecorder).
 		ToControllers()
 	if err != nil {
@@ -168,6 +163,7 @@ var deploymentConfigMaps = []revision.RevisionResource{
 	{Name: "kube-controller-manager-pod"},
 
 	{Name: "config"},
+	{Name: "cluster-policy-controller-config"},
 	{Name: "controller-manager-kubeconfig"},
 	{Name: "cloud-config", Optional: true},
 	{Name: "kube-controller-cert-syncer-kubeconfig"},
